//
//  ProductController.h
//  ProductSupport
//
//  Created by li bo on 5/14/08.
//  Copyright 2008 MingJie. All rights reserved.
//

/*
 *   该框架封装了产品化支持的常用功能，包括4个方面
 *      1. 自动更新支持
 *          使用Sparkle完成自动更新功能，提供checkUpdates事件以完成手动更新功能。
 *          自动更新地址需要在主程序Info.plist里面设置Key为SUFeedURL的内容。
 *      2. About对话框
 *          读取主程序Resources目录下的Credits.rtf文件内容并显示在About对话框中。
 *      3. 注册相关界面和功能
 *          主程序必须在applicationDidFinishLaunching被处理前调用setEncryptTemplate设置加密模板，
 *          主程序可以调用isRegister检查用户是否注册，调用registerUser获得注册用户名。
 *          用户注册完成后会发送带用户名的userDidFinishRegistration notification。
 *      4. 访问网站相关功能 
 *          在主程序的Info.plist中设置以下Key 即可在Help菜单中显示相应的菜单项，没有设置Key，则相应菜单不显示
 *              Key (字符串)     菜单项内容           功能
 *              ------------------------------------------------------
 *              WebSiteURL      Visit WebSite       访问网站主页
 *              OrderURL        Order Now           访问购买页面
 *              FaqURL          Read Faq            访问Faq页面
 *              SupportEMail    Email Support       调用Mail写Feedback
 *              OnlineHelpURL   Read Online Help    访问在线帮助页面
 *
 *  用户可以在NIB中实例化ProductController或者在程序中使用alloc实例化
 */

#import <Cocoa/Cocoa.h>

@class SUUpdater;
@class AboutWindowController;
@class RegisterWindowController;

@interface ProductController : NSObject {
	AboutWindowController*			aboutWindow;
	RegisterWindowController*		registerWindow;
#if !defined(_APPSTORE_VERSION)
	SUUpdater*						updater;
#endif
    NSDictionary*                   infoDictionary;
    
    NSBundle*                       bundle;
}

+ (BOOL)isRegister;
+ (NSString*)registerUser;
+ (void)setEncryptTemplate:(NSString*)theTemplate;

//help menu support
- (IBAction)openWebsiteURL:(id)sender;
- (IBAction)openFaqURL:(id)sender;
- (IBAction)openOrderURL:(id)sender;
- (IBAction)openEmailSupport:(id)sender;
- (IBAction)openOnlineHelp:(id)sender;

- (IBAction)checkUpdates:(id)sender;

- (IBAction)openAbout:(id)sender;
- (IBAction)openRegister:(id)sender;


@end
